==> domframework_0.55.orig.tar.bz2: domframework-0.55/Tests/authhtpasswdTest.php <==
<?php
/** DomFramework - Tests
    @package domframework
    @author Dominique Fournier <dominique@fournier38.fr> */

/** Test the authhtpasswd.php file */
class test_authhtpasswd extends PHPUnit_Framework_TestCase
{
  public function test_clean ()
  {
    @unlink ("/tmp/htpasswd.file");
    file_put_contents ("/tmp/htpasswd.file",
    'toto@toto.com:$2y$05$dO7qyX4simzg3pMgWyqHgeAjFauXEyUdPdyrwDMVNj4fTuE24TGuq'
     ."\n".
    'titi@titi.com:$2y$05$dO7qyX4simzg3pMgWyqHgeAjFauXEyUdPdyrwDMVNj4fTuE24TGuq'
     ."\n"
    );
  }

  public function test_connect ()
  {
    $authhtpasswd = new authhtpasswd ();
    $authhtpasswd->htpasswdFile = "/tmp/htpasswd.file";
    $res = $authhtpasswd->connect ();
    $this->assertSame ($res, null);
  }

  public function test_authentication1 ()
  {
    $authhtpasswd = new authhtpasswd ();
    $authhtpasswd->htpasswdFile = "/tmp/htpasswd.file";
    $res = $authhtpasswd->authentication ("toto@toto.com", "toto123");
    $this->assertSame ($res, true);
  }

  public function test_authentication2 ()
  {
    $authhtpasswd = new authhtpasswd ();
    $authhtpasswd->htpasswdFile = "/tmp/htpasswd.file";
    $this->setExpectedException ("Exception");
    $res = $authhtpasswd->authentication ("UNKNOWN@toto.com", "toto123");
  }

  public function test_authentication3 ()
  {
    $authhtpasswd = new authhtpasswd ();
    $authhtpasswd->htpasswdFile = "/tmp/htpasswd.file";
    $this->setExpectedException ("Exception");
    $res = $authhtpasswd->authentication ("toto@toto.com", "BAD PASSWD");
  }

  public function test_authentication4 ()
  {
    $authhtpasswd = new authhtpasswd ();
    $authhtpasswd->htpasswdFile = "/tmp/htpasswd.file";
    $res = $authhtpasswd->authentication ("titi@titi.com", "toto123");
    $this->assertSame ($res, true);
  }
}

==> domframework_0.60.orig.tar.bz2: domframework-0.60/Tests/authhtpasswdTest.php <==
<?php
/** DomFramework - Tests
    @package domframework
    @author Dominique Fournier <dominique@fournier38.fr> */

/** Test the authhtpasswd.php file */
class authhtpasswdTest extends PHPUnit_Framework_TestCase
{
  public function test_clean ()
  {
    @unlink ("/tmp/htpasswd.file");
    file_put_contents ("/tmp/htpasswd.file",
    'toto@toto.com:$2y$05$dO7qyX4simzg3pMgWyqHgeAjFauXEyUdPdyrwDMVNj4fTuE24TGuq'
     ."\n".
    'titi@titi.com:$2y$05$dO7qyX4simzg3pMgWyqHgeAjFauXEyUdPdyrwDMVNj4fTuE24TGuq'
     ."\n"
    );
  }

  public function test_connect ()
  {
    $authhtpasswd = new authhtpasswd ();
    $authhtpasswd->htpasswdFile = "/tmp/htpasswd.file";
    $res = $authhtpasswd->connect ();
    $this->assertSame ($res, null);
  }

  public function test_authentication1 ()
  {
    $authhtpasswd = new authhtpasswd ();
    $authhtpasswd->htpasswdFile = "/tmp/htpasswd.file";
    $res = $authhtpasswd->authentication ("toto@toto.com", "toto123");
    $this->assertSame ($res, true);
  }

  public function test_authentication2 ()
  {
    $authhtpasswd = new authhtpasswd ();
    $authhtpasswd->htpasswdFile = "/tmp/htpasswd.file";
    $this->setExpectedException ("Exception");
    $res = $authhtpasswd->authentication ("UNKNOWN@toto.com", "toto123");
  }

  public function test_authentication3 ()
  {
    $authhtpasswd = new authhtpasswd ();
    $authhtpasswd->htpasswdFile = "/tmp/htpasswd.file";
    $this->setExpectedException ("Exception");
    $res = $authhtpasswd->authentication ("toto@toto.com", "BAD PASSWD");
  }

  public function test_authentication4 ()
  {
    $authhtpasswd = new authhtpasswd ();
    $authhtpasswd->htpasswdFile = "/tmp/htpasswd.file";
    $res = $authhtpasswd->authentication ("titi@titi.com", "toto123");
    $this->assertSame ($res, true);
  }
}
